import { Package, Version, Author } from '@verdaccio/types';
import { getConflict, getBadData, getBadRequest, getInternalError, getUnauthorized, getForbidden, getServiceUnavailable, getNotFound, getCode } from '@verdaccio/commons-api';
/**
 * From normalize-package-data/lib/fixer.js
 * @param {*} name  the package name
 * @return {Boolean} whether is valid or not
 * @deprecated
 */
export declare function validateName(name: string): boolean;
/**
 * Validate a package.
 * @return {Boolean} whether the package is valid or not
 * @deprecated
 */
export declare function validatePackage(name: string): boolean;
/**
 * Check whether an element is an Object
 * @param {*} obj the element
 * @return {Boolean}
 * @deprecated
 */
export declare function isObject(obj: any): boolean;
/**
 * Validate the package metadata, add additional properties whether are missing within
 * the metadata properties.
 * @param {*} object
 * @param {*} name
 * @return {Object} the object with additional properties as dist-tags ad versions
 * @deprecated
 */
export declare function validateMetadata(object: Package, name: string): Package;
/**
 * Gets version from a package object taking into account semver weirdness.
 * @return {String} return the semantic version of a package
 */
export declare function getVersion(pkg: Package, version: any): Version | void;
/**
 * Function filters out bad semver versions and sorts the array.
 * @return {Array} sorted Array
 */
export declare function semverSort(listVersions: string[]): string[];
/**
 * Flatten arrays of tags.
 * @param {*} data
 */
export declare function normalizeDistTags(pkg: Package): void;
export declare function getLatestVersion(pkgInfo: Package): string;
export declare const ErrorCode: {
    getConflict: typeof getConflict;
    getBadData: typeof getBadData;
    getBadRequest: typeof getBadRequest;
    getInternalError: typeof getInternalError;
    getUnauthorized: typeof getUnauthorized;
    getForbidden: typeof getForbidden;
    getServiceUnavailable: typeof getServiceUnavailable;
    getNotFound: typeof getNotFound;
    getCode: typeof getCode;
};
export declare function buildToken(type: string, token: string): string;
export declare type AuthorFormat = Author | string | null | void;
/**
 * Formats author field for webui.
 * @see https://docs.npmjs.com/files/package.json#author
 * @param {string|object|undefined} author
 */
export declare function formatAuthor(author: AuthorFormat): any;
/**
 * Apply whitespaces based on the length
 * @param {*} str the log message
 * @return {String}
 */
export declare function pad(str: any, max: any): string;
/**
 * return a masquerade string with its first and last {charNum} and three dots in between.
 * @param {String} str
 * @param {Number} charNum
 * @returns {String}
 */
export declare function mask(str: string, charNum?: number): string;
export declare function hasDiffOneKey(versions: any): boolean;
export declare function isVersionValid(packageMeta: any, packageVersion: any): boolean;
